using System;
using System.IO;
using System.Data;
using System.Data.SqlClient;
using System.Collections;
using System.Collections.Generic;

using Altiris.Common;
using Altiris.NS;
using Altiris.NS.ContextManagement;
using Altiris.NS.ItemManagement;
using Altiris.NS.Security;
using Altiris.NS.Logging;
using Altiris.Resource;

class UpdateComponentState
{

    public static readonly Guid SYMC_ADMIN_ROLE = new Guid("2E1F478A-4986-4223-9D1E-B5920A63AB41");

   #region Helper Methods
   //
   //
   static public void DoUpdate()
   {
       List<Guid> AcPrivileges = new List<Guid>();

       AcPrivileges.Add(new Guid("8d0e7c89-1004-4ece-ad01-24e77451f725")); //Configure software usage tracking
       AcPrivileges.Add(new Guid("919af301-4569-49d8-ae8d-c8000f649df5")); //Create software licenses
       AcPrivileges.Add(new Guid("cd78be01-42ba-4ae2-8710-58004e05f27c")); //Create software deliveries
       AcPrivileges.Add(new Guid("e720c974-5c4a-4779-bc1d-4904c6d5b48e")); //Define software product inventory filters
       AcPrivileges.Add(new Guid("03302d4e-7fef-4984-afa8-ed842f97b355")); //Create software products

       try
       {
           //Ensure all new Software Management privileges have been granted to the Symantec Administrators Role
           Altiris.NS.Security.Role symcAdmin = Altiris.NS.Security.SecurityRoleManager.Get(SYMC_ADMIN_ROLE);

           if (symcAdmin != null)
           {
               foreach (Guid privilege in AcPrivileges)
               {
                   //Check each new SW Management privilege has been granted to the SYMC Admins role...if not, then add it
                   Altiris.NS.Security.Privilege nsPrivilege = Altiris.NS.Security.SecurityPrivilegeManager.Get(privilege);
                   Altiris.NS.Security.TrusteeCollection members = Altiris.NS.Security.SecurityPrivilegeManager.GetMembers(nsPrivilege);
                   if (!members.Contains(symcAdmin.Trustee))
                   {
                       Console.WriteLine(String.Format("Role is NOT currently granted privilege '{0}' - fixing...", nsPrivilege.Name));
                       members.Add(symcAdmin.Trustee);
                       Altiris.NS.Security.SecurityPrivilegeManager.SetMembers(nsPrivilege, members);
                   } 
                   else
                       Console.WriteLine(String.Format("Role is currently granted privilege '{0}' - skipping...", nsPrivilege.Name));
               }
           }
           else
               Console.WriteLine("There is a major problem with the Symantec Administrators role - cannot update");
       }
       catch (Exception ex)
       {
           System.Console.WriteLine(String.Format("Unable to grant software privileges to SYMC Administrators role {0} \r\n\r\nStackTrace:{1}", ex.Message, ex.StackTrace));
       }
     
   }

   #endregion

   static void Main(string[] args)
   {
      //
      //	Set the security context for the current user
      //
      SecurityContextManager.SetContextData();

      int count;

      Console.WriteLine("Checking Symantec Administrators role...");
      DoUpdate();
      Console.WriteLine("\nDone!");
      
       //
      //	Free the security context for the current user
      //
      SecurityContextManager.FreeContextData();
   }

}